#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed May  3 08:09:12 2023

@author: anton
"""
from SLiCAP import *
prj = initProject('LNA')
i1  = instruction()

fileNames = ['LNAgain', 'LNAzin', 'LNAnoise']

# Specs
Rs = 50 # Ohm
NF = 1  # dB
Av = 20 # V/V

for fi in fileNames:
    i1.setCircuit(fi + '.cir')
    i1.defPar("R_s", Rs)
    htmlPage('Circuit data')
    head2html('Circuit diagram')
    img2html(fi + '.svg', 700)
    netlist2html(fi + '.cir')
    elementData2html(i1.circuit)
    params2html(i1.circuit)
    i1.setSimType('numeric')
    if fi == 'LNAgain':
        i1.setSource('V1')
        i1.setDetector(['V_outP', 'V_outN'])
        i1.setGainType('gain')
        i1.setDataType('laplace')
        
        gain = i1.execute().laplace
        head2html('Voltage transfer')
        eqn2html('A_v', gain)
        
    elif fi == 'LNAzin':
        i1.setSource('I1')
        i1.setDetector('V_in')
        i1.setGainType('gain')
        i1.setDataType('laplace')
        
        zin = i1.execute().laplace
        head2html('Input impedance')
        eqn2html('Z_i', zin, units='Omega')
        
    elif fi == 'LNAnoise':
        i1.setSource('V1')
        i1.setDetector(['V_outP', 'V_outN'])
        i1.setGainType('vi')
        i1.setDataType('noise')
        noise    = i1.execute()
        inoise   = noise.inoise
        srcNoise = noise.inoiseTerms['V1']
        NF_lin   = sp.simplify(inoise/srcNoise)
        head2html('Noie figure')
        eqn2html('NF', 10*sp.log(NF_lin)/sp.log(10), units='dB')
        
R_1, R_2, R_3 = sp.symbols('R_1, R_2, R_3')        
sol = sp.solve([gain - Av, zin - Rs, NF_lin - 10**(NF/10)], R_1, R_2, R_3)[0]

ini.htmlIndex = 'index.html'
htmlPage('Solution')
text2html('The source-load transfer, the input impedance, and the noise ' +
          'figure are according to the requirements if:')
eqn2html(R_1, sol[0])
eqn2html(R_2, sol[1])
eqn2html(R_3, sol[2])